//! This module contains helper functions for implementing CLI/TUI.

use crate::time::{parse_time, Time};
use console::style;
use std::{
	fmt::Display,
	io::{self, BufRead as _, Write as _}
};

pub fn ask(question: impl Display) -> String {
	let mut stdout = io::stdout().lock();
	let mut stdin = io::stdin().lock();

	write!(
		stdout,
		"{} {} ",
		style(question).bold().magenta(),
		style(">").cyan()
	)
	.unwrap();
	stdout.flush().unwrap();
	let mut line = String::new();
	stdin.read_line(&mut line).unwrap();
	line.trim().to_owned()
}

pub fn ask_time(question: impl Display + Copy) -> Time {
	let mut stdout = io::stdout().lock();
	let mut stdin = io::stdin().lock();

	let mut line = String::new();
	loop {
		line.clear();
		write!(
			stdout,
			"{} {} ",
			style(question).bold().magenta(),
			style(">").cyan()
		)
		.unwrap();
		stdout.flush().unwrap();
		stdin.read_line(&mut line).unwrap();
		let line = line.trim();
		match parse_time(line) {
			Ok(time) => return time,
			Err(err) => writeln!(
				stdout,
				"{} {line:?}: {err}",
				style("Invalid Input").bold().red()
			)
			.unwrap()
		}
	}
}
